==> open-vulnerability-clients-7.2.2-sources.jar: io/github/jeremylong/openvulnerability/client/HttpAsyncClientSupplier.java <==
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 * Copyright (c) 2023-2025 Jeremy Long. All Rights Reserved.
 */
package io.github.jeremylong.openvulnerability.client;

import org.apache.hc.client5.http.impl.async.CloseableHttpAsyncClient;
import org.apache.hc.client5.http.impl.async.HttpAsyncClients;
import org.apache.hc.client5.http.impl.routing.SystemDefaultRoutePlanner;

import java.net.ProxySelector;
import java.util.function.Supplier;

/**
 * Supplier for {@link CloseableHttpAsyncClient}s.
 * <p>
 * May be used to provide customized HTTP clients to data source clients.
 * <p>
 * Closing of the supplied {@link CloseableHttpAsyncClient} instances is a responsibility of the caller.
 */
@FunctionalInterface
public interface HttpAsyncClientSupplier extends Supplier<CloseableHttpAsyncClient> {

    static HttpAsyncClientSupplier getDefault() {
        return () -> {
            SystemDefaultRoutePlanner planner = new SystemDefaultRoutePlanner(ProxySelector.getDefault());
            return HttpAsyncClients.custom().setRoutePlanner(planner).useSystemProperties().build();
        };
    }

}

==> open-vulnerability-clients-7.3.2-sources.jar: io/github/jeremylong/openvulnerability/client/HttpAsyncClientSupplier.java <==
/*
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 * Copyright (c) 2023-2025 Jeremy Long. All Rights Reserved.
 */
package io.github.jeremylong.openvulnerability.client;

import org.apache.hc.client5.http.config.ConnectionConfig;
import org.apache.hc.client5.http.impl.async.CloseableHttpAsyncClient;
import org.apache.hc.client5.http.impl.async.HttpAsyncClients;
import org.apache.hc.client5.http.impl.nio.PoolingAsyncClientConnectionManager;
import org.apache.hc.client5.http.impl.nio.PoolingAsyncClientConnectionManagerBuilder;
import org.apache.hc.client5.http.impl.routing.SystemDefaultRoutePlanner;
import org.apache.hc.core5.util.TimeValue;
import org.apache.hc.core5.util.Timeout;

import java.net.ProxySelector;
import java.util.function.Supplier;

/**
 * Supplier for {@link CloseableHttpAsyncClient}s.
 * <p>
 * May be used to provide customized HTTP clients to data source clients.
 * <p>
 * Closing of the supplied {@link CloseableHttpAsyncClient} instances is a responsibility of the caller.
 */
@FunctionalInterface
public interface HttpAsyncClientSupplier extends Supplier<CloseableHttpAsyncClient> {

    static HttpAsyncClientSupplier getDefault() {
        return () -> {
            SystemDefaultRoutePlanner planner = new SystemDefaultRoutePlanner(ProxySelector.getDefault());
            final PoolingAsyncClientConnectionManager connectionManager = PoolingAsyncClientConnectionManagerBuilder
                    .create().setDefaultConnectionConfig(ConnectionConfig.custom()
                            .setSocketTimeout(Timeout.ofMinutes(1)).setConnectTimeout(Timeout.ofMinutes(1)).build())
                    .useSystemProperties().build();
            return HttpAsyncClients.custom().setRoutePlanner(planner).setConnectionManager(connectionManager)
                    .useSystemProperties().build();
        };
    }

}
